@@ -1,19 +1,18 @@
 /*
  * File: link.rs
  * Project: src
- * Created Date: 24/05/2021
+ * Created Date: 27/04/2022
  * Author: Shun Suzuki
  * -----
- * Last Modified: 16/12/2021
+ * Last Modified: 02/05/2022
  * Modified By: Shun Suzuki (suzuki@hapis.k.u-tokyo.ac.jp)
  * -----
- * Copyright (c) 2021 Hapis Lab. All rights reserved.
+ * Copyright (c) 2022 Hapis Lab. All rights reserved.
  *
  */
 
 use anyhow::Result;
-
-use crate::hardware_defined::{RxDatagram, TxDatagram};
+use autd3_driver::{RxDatagram, TxDatagram};
 
 /// Link is a interface to the AUTD device.
 pub trait Link: Send {
@@ -21,5 +20,6 @@ pub trait Link: Send {
     fn close(&mut self) -> Result<()>;
     fn send(&mut self, tx: &TxDatagram) -> Result<bool>;
     fn receive(&mut self, rx: &mut RxDatagram) -> Result<bool>;
+    fn cycle_ticks(&self) -> u16;
     fn is_open(&self) -> bool;
 }
